pub struct Topic<T: 'static> { /* private fields */ }Expand description
Type-safe event topic.
T is the payload type associated with the topic. Two topics are equal only
when both the topic name and payload type match.
Implementations
Sourceimpl<T: 'static> Topic<T>
impl<T: 'static> Topic<T>
Sourcepub fn try_new(name: impl Into<String>) -> EventBusResult<Self>
pub fn try_new(name: impl Into<String>) -> EventBusResult<Self>
Creates a topic after validating its name.
Parameters
name: Non-blank topic name.
Returns
A type-safe topic bound to T.
Errors
Returns EventBusError::InvalidArgument when name is blank.
Sourcepub fn payload_type_id(&self) -> TypeId
pub fn payload_type_id(&self) -> TypeId
Sourcepub fn payload_type_name(&self) -> &'static str
pub fn payload_type_name(&self) -> &'static str